SoftUiThemeMetrics class base

Inheritance
Implementers
Annotations

Constructors

SoftUiThemeMetrics({required double small, required double medium, required double large, required double icon, required double blur, required BorderSide? border, required Radius radius, required BoxShadow? shadow, required Size sidebar, required Size header, required Size footer, required Size button, required EdgeInsets buttonPadding, required Size field, required EdgeInsets fieldPadding, required Curve curve, required Duration duration})
const

Properties

blur double
final
border BorderSide?
final
button Size
final
buttonPadding EdgeInsets
final
curve Curve
final
duration Duration
final
field Size
final
fieldPadding EdgeInsets
final
final
hashCode int
The hash code for this object.
no setterinherited
final
icon double
final
large double
final
medium double
final
radius Radius
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow BoxShadow?
final
final
small double
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({double? xsmall, double? small, double? medium, double? large, double? xlarge, double? xxlarge, double? icon, double? blur, BorderSide? border, Radius? radius, BoxShadow? shadow, Size? sidebar, Size? header, Size? footer, Size? button, EdgeInsets? buttonPadding, Size? field, EdgeInsets? fieldPadding, Curve? curve, Duration? duration}) ThemeExtension<SoftUiThemeMetrics>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<SoftUiThemeMetrics>? other, double t) ThemeExtension<SoftUiThemeMetrics>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited