SoftUiMetrics class final

Inheritance
Annotations

Constructors

SoftUiMetrics({double small = 8, double medium = 16, double large = 24, double icon = 18, double blur = 0, BorderSide? border, Radius radius = const Radius.circular(8), BoxShadow? shadow, Size sidebar = const Size(60, double.infinity), Size header = Size.zero, Size footer = Size.zero, Size button = const Size(double.infinity, 28), EdgeInsets buttonPadding = const EdgeInsets.symmetric(horizontal: 8), Size field = const Size(260, 30), EdgeInsets fieldPadding = const EdgeInsets.symmetric(horizontal: 8), Curve curve = Curves.easeInOutCubic, Duration duration = const Duration(milliseconds: 200)})
const
SoftUiMetrics.glassmorphism(SoftUiThemeColors colors)
factory
SoftUiMetrics.neumorphism(SoftUiThemeColors colors)
factory

Properties

blur double
finalinherited
border BorderSide?
finalinherited
button Size
finalinherited
buttonPadding EdgeInsets
finalinherited
curve Curve
finalinherited
duration Duration
finalinherited
field Size
finalinherited
fieldPadding EdgeInsets
finalinherited
finalinherited
hashCode int
The hash code for this object.
no setterinherited
finalinherited
icon double
finalinherited
large double
finalinherited
medium double
finalinherited
radius Radius
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow BoxShadow?
finalinherited
finalinherited
small double
finalinherited
type Object
The extension's type.
no setterinherited

Methods

copyWith({double? xsmall, double? small, double? medium, double? large, double? xlarge, double? xxlarge, double? icon, double? blur, BorderSide? border, Radius? radius, BoxShadow? shadow, Size? sidebar, Size? header, Size? footer, Size? button, EdgeInsets? buttonPadding, Size? field, EdgeInsets? fieldPadding, Curve? curve, Duration? duration}) ThemeExtension<SoftUiThemeMetrics>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
inherited
lerp(covariant ThemeExtension<SoftUiThemeMetrics>? other, double t) ThemeExtension<SoftUiThemeMetrics>
Linearly interpolate with another ThemeExtension object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited