SoftUiTheme class final
Constructors
- SoftUiTheme({bool isGlassmorphism = false, bool isNeumorphism = true, SoftUiThemeColors? lightColors, SoftUiThemeColors? darkColors, SoftUiThemeMetrics glassMetrics(SoftUiThemeColors colors)?, SoftUiThemeMetrics neumoMetrics(SoftUiThemeColors colors)?})
-
const
Properties
- darkColors → SoftUiThemeColors?
-
final
- glassMetrics → SoftUiThemeMetrics Function(SoftUiThemeColors colors)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isGlassmorphism → bool
-
final
- isNeumorphism → bool
-
final
- lightColors → SoftUiThemeColors?
-
final
- neumoMetrics → SoftUiThemeMetrics Function(SoftUiThemeColors colors)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
{bool isDark = false}) → ThemeData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited