SoftUiPage class final

Inheritance

Constructors

SoftUiPage({bool useGradient = false, bool isExtended = false, Size headerSize = const Size.fromHeight(55), Color? color, LinearGradient? gradient, EdgeInsets? padding, Widget? header, Widget? body, Widget? footer, Widget? child, Key? key})
const
SoftUiPage.desktop({bool useGradient = false, Size headerSize = const Size.fromHeight(40), Widget? header, Widget? body, Widget? footer, Color? color, LinearGradient? gradient, Widget? sidebar})
factory
SoftUiPage.mobile({bool useGradient = false, Size headerSize = const Size.fromHeight(120), EdgeInsets? padding, Widget? header, Widget? body, Widget? footer, Color? color, LinearGradient? gradient})
factory

Properties

body Widget?
final
child Widget?
final
color Color?
final
final
gradient LinearGradient?
final
hashCode int
The hash code for this object.
no setterinherited
final
headerSize Size
final
isExtended bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useGradient bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited