SoftUiMetrics class
final
Constructors
-
SoftUiMetrics({double small = 8, double medium = 16, double large = 24, double icon = 18, double blur = 0, BorderSide? border, Radius radius = const Radius.circular(8), BoxShadow? shadow, Size button = const Size(double.infinity, 28), EdgeInsets buttonPadding = const EdgeInsets.symmetric(horizontal: 8), Size field = const Size(260, 30), EdgeInsets fieldPadding = const EdgeInsets.symmetric(horizontal: 8), Curve curve = Curves.easeInOutCubic, Duration duration = const Duration(milliseconds: 200)})
-
const
-
SoftUiMetrics.glassmorphism(SoftUiThemeColors colors)
-
factory
-
SoftUiMetrics.neumorphism(SoftUiThemeColors colors)
-
factory
Methods
-
copyWith({double? xsmall, double? small, double? medium, double? large, double? xlarge, double? xxlarge, double? icon, double? blur, BorderSide? border, Radius? radius, BoxShadow? shadow, Size? button, EdgeInsets? buttonPadding, Size? field, EdgeInsets? fieldPadding, Curve? curve, Duration? duration})
→ ThemeExtension<SoftUiThemeMetrics>
-
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
inherited
-
lerp(covariant ThemeExtension<SoftUiThemeMetrics>? other, double t)
→ ThemeExtension<SoftUiThemeMetrics>
-
Linearly interpolate with another ThemeExtension object.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited